@@ -52,6 +52,12 @@ $config = array(
 	/*
 	'example-userpass' => array(
 		'exampleauth:UserPass',
+
+		// Give the user an option to save their username for future login attempts
+		// And when enabled, what should the default be, to save the username or not
+		//'remember.username.enabled' => FALSE,
+		//'remember.username.checked' => FALSE,
+
 		'student:studentpass' => array(
 			'uid' => array('test'),
 			'eduPersonAffiliation' => array('member', 'student'),
@@ -63,6 +69,28 @@ $config = array(
 	),
 	*/
 
+	/*
+	'crypto-hash' => array(
+		'authcrypt:Hash',
+		// hashed version of 'verysecret', made with bin/pwgen.php
+		'professor:{SSHA256}P6FDTEEIY2EnER9a6P2GwHhI5JDrwBgjQ913oVQjBngmCtrNBUMowA==' => array(
+			'uid' => array('prof_a'),
+			'eduPersonAffiliation' => array('member', 'employee', 'board'),
+		),
+	),
+	*/
+
+	/*
+	'htpasswd' => array(
+		'authcrypt:Htpasswd',
+		'htpasswd_file' => '/var/www/foo.edu/legacy_app/.htpasswd',
+		'static_attributes' => array(
+			'eduPersonAffiliation' => array('member', 'employee'),
+			'Organization' => array('University of Foo'),
+		),
+	),
+	*/
+
 	/*
 	// This authentication source serves as an example of integration with an
 	// external authentication engine. Take a look at the comment in the beginning
@@ -89,6 +117,8 @@ $config = array(
 		// 'sreg.validate' => FALSE,
 		'attributes.ax_required' => array('http://axschema.org/namePerson/friendly'),
 		'attributes.ax_optional' => array('http://axschema.org/namePerson','http://axschema.org/contact/email'),
+		// Prefer HTTP redirect over POST
+		// 'prefer_http_redirect' => FALSE,
 	),
 	*/
 
@@ -129,8 +159,14 @@ $config = array(
 	/*
 	'facebook' => array(
 		'authfacebook:Facebook',
+		// Register your Facebook application on http://www.facebook.com/developers
+		// App ID or API key (requests with App ID should be faster; https://github.com/facebook/php-sdk/issues/214)
 		'api_key' => 'xxxxxxxxxxxxxxxx',
+		// App Secret
 		'secret' => 'xxxxxxxxxxxxxxxx',
+		// which additional data permissions to request from user
+		// see http://developers.facebook.com/docs/authentication/permissions/ for the full list
+		// 'req_perms' => 'email,user_birthday',
 	),
 	*/
 
@@ -183,6 +219,11 @@ $config = array(
 	'example-ldap' => array(
 		'ldap:LDAP',
 
+		// Give the user an option to save their username for future login attempts
+		// And when enabled, what should the default be, to save the username or not
+		//'remember.username.enabled' => FALSE,
+		//'remember.username.checked' => FALSE,
+
 		// The hostname of the LDAP server.
 		'hostname' => 'ldap.example.org',
 
@@ -248,6 +289,11 @@ $config = array(
 	'example-ldapmulti' => array(
 		'ldap:LDAPMulti',
 
+		// Give the user an option to save their username for future login attempts
+		// And when enabled, what should the default be, to save the username or not
+		//'remember.username.enabled' => FALSE,
+		//'remember.username.checked' => FALSE,
+
 		// The way the organization as part of the username should be handled.
 		// Three possible values:
 		// - 'none':   No handling of the organization. Allows '@' to be part
