@@ -2,7 +2,7 @@
 /* 
  * The configuration of simpleSAMLphp
  * 
- * $Id: config.php 3082 2012-05-03 11:53:56Z comel.ah $
+ * $Id: config.php 3171 2012-09-25 08:54:06Z jaimepc@gmail.com $
  */
 
 $config = array (
@@ -274,7 +274,7 @@ $config = array (
 	/*
 	 * Languages available, RTL languages, and what language is default
 	 */
-	'language.available'	=> array('en', 'no', 'nn', 'se', 'da', 'de', 'sv', 'fi', 'es', 'fr', 'it', 'nl', 'lb', 'cs', 'sl', 'lt', 'hr', 'hu', 'pl', 'pt', 'pt-br', 'tr', 'ja', 'zh', 'zh-tw', 'ru', 'et', 'he', 'id'),
+	'language.available'	=> array('en', 'no', 'nn', 'se', 'da', 'de', 'sv', 'fi', 'es', 'fr', 'it', 'nl', 'lb', 'cs', 'sl', 'lt', 'hr', 'hu', 'pl', 'pt', 'pt-br', 'tr', 'ja', 'zh', 'zh-tw', 'ru', 'et', 'he', 'id', 'sr'),
 	'language.rtl'		=> array('ar','dv','fa','ur','he'),
 	'language.default'		=> 'en',
 
