@@ -50,6 +50,14 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception {
 	private $parameters;
 
 
+	/**
+	 * Name of custom include template for the error.
+	 *
+	 * @var string|NULL
+	 */
+	protected $includeTemplate = NULL;
+
+
 	/**
 	 * Constructor for this error.
 	 *
@@ -217,6 +225,7 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception {
 		$data['module'] = $this->module;
 		$data['dictTitle'] = $this->dictTitle;
 		$data['dictDescr'] = $this->dictDescr;
+		$data['includeTemplate'] = $this->includeTemplate;
 
 		/* Check if there is a valid technical contact email address. */
 		if($config->getString('technicalcontact_email', 'na@example.org') !== 'na@example.org') {
@@ -233,7 +242,7 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception {
 			$data['email'] = '';
 		}
 
-		$show_function = $config->getString('errors.show_function', NULL);
+		$show_function = $config->getArray('errors.show_function', NULL);
 		if (isset($show_function)) {
 			assert('is_callable($show_function)');
 			call_user_func($show_function, $config, $data);
